@@ -51,7 +51,7 @@ def excecuteElement(config,records,ps_delete_query):
     except (Exception, psycopg2.Error) as error:
         print("Error while connecting to PostgreSQL :", error)
         res = -1
-        writeLogTxt(name=getNameFileOutput()+'_Log.txt',data="Error excecuteElement : " + str(error),root_directory_name="",dir_name = '_LOG_Postgres')
+        writeLogTxt(name=getNameFileOutput()+'_Log.txt',data="Error excecuteElement : " + str(error)+('**'*45)+'\n\n',root_directory_name="",dir_name = '_LOG_Postgres')
     finally:
         # closing database connection.
         if connection:
@@ -83,7 +83,7 @@ def selectElement(config,where,sql_select_query,one=False):
             record = cursor.fetchall()
     except (Exception, psycopg2.Error) as error:
         print("Error in update operation", error)
-        writeLogTxt(name=getNameFileOutput()+'_Log.txt',data="Error selectElement : "+ str(error) ,root_directory_name="",dir_name = '_LOG_Postgres')
+        writeLogTxt(name=getNameFileOutput()+'_Log.txt',data="Error selectElement : "+ str(error)+('**'*45)+'\n\n' ,root_directory_name="",dir_name = '_LOG_Postgres')
 
     finally:
         # closing database connection.
@@ -111,7 +111,7 @@ def excecuteSQL(config,sql_query):
         res = True
     except (Exception, psycopg2.Error) as error:
         print("Error while connecting to PostgreSQL :", error)
-        writeLogTxt(name=getNameFileOutput()+'_Log.txt',data="Error excecuteSQL : "+str(error),root_directory_name="",dir_name = '_LOG_Postgres')
+        writeLogTxt(name=getNameFileOutput()+'_Log.txt',data="Error excecuteSQL : "+str(error)+('**'*45)+'\n\n',root_directory_name="",dir_name = '_LOG_Postgres')
     finally:
         # closing database connection.
         if connection:
